@@ -151,9 +151,7 @@ class settings(settingsMeta('settings', (object,), {})):
                     kwargs[setting.name] = getattr(defaults, setting.name)
                 else:
                     if kwargs[setting.name] != setting.future_default:
-                        if (
-                            setting.deprecation_message is not None
-                        ):
+                        if setting.deprecation_message is not None:
                             deprecations.append(setting)
                     if setting.validator:
                         kwargs[setting.name] = setting.validator(
@@ -517,6 +515,9 @@ class HealthCheck(Enum):
     hung_test = 6
     """Checks if your tests have been running for a very long time."""
 
+    large_base_example = 7
+    """Checks if the natural example to shrink towards is very large."""
+
 
 @unique
 class Statistics(IntEnum):
