@@ -17,8 +17,6 @@
 
 from __future__ import division, print_function, absolute_import
 
-import warnings
-
 
 class HypothesisException(Exception):
 
@@ -174,14 +172,15 @@ class FailedHealthCheck(HypothesisException, Warning):
     """Raised when a test fails a preliminary healthcheck that occurs before
     execution."""
 
+    def __init__(self, message, check):
+        super(FailedHealthCheck, self).__init__(message)
+        self.health_check = check
 
-class HypothesisDeprecationWarning(HypothesisException, DeprecationWarning):
+
+class HypothesisDeprecationWarning(HypothesisException, FutureWarning):
     pass
 
 
-warnings.simplefilter('once', HypothesisDeprecationWarning)
-
-
 class Frozen(HypothesisException):
 
     """Raised when a mutation method has been called on a ConjectureData object
